#!/bin/bash

nodeIp="{{ nodeIp }}"
port="{{ port }}"
target="{{ target }}"
reportWorkDir="{{ reportWorkDir }}"
archiveName="{{ archiveName }}"
archiveNameFull="${archiveName}.tar.gz"
errMsg=""

if [ -z "${target}" ]; then
  echo "Target is not set."
  exit 1
fi

if [ -z "${nodeIp}" ]; then
  echo "Node Ip is not set."
  exit 1
fi

if [ "$(ss -l src ":${port}" | wc -l)" -ne "1" ]; then
  echo "Port ${port} in use, please set another port."
  exit 1
fi

nc_listen() {
    local node=${1}
    nc -q 1 -lp ${port} | tar -x || errMsg="${errMsg}Failed to collect report for ${node}\n"
}

cd ${reportWorkDir}
for node in $(salt -C "${target}" --out txt test.ping | cut -f 1 -d ':'); do
  nc_listen ${node} &
  sleep 2 # wait until socket initialized
  salt -C "${node}" cmd.run "bash /var/tmp/sosreport_send.sh ${nodeIp} ${port}"
  sleep 2 # wait until socket released
done

if [ -z "${errMsg}" ]; then
  tar -czf "${archiveName}.tar.gz" sosreport-*
  echo "Report created: ${reportWorkDir}/${archiveNameFull}"
else
  echo -e "${errMsg}"
  echo "Report can't be created."
  exit 1
fi
